Crate near_chain_primitives

Crate near_chain_primitives 

Re-exports

pub use error::Error;

Modules

error

Enums

ApplyChunksMode
apply_chunks may be called in two code paths, through process_block or through catchup_blocks When it is called through process_block, it is possible that the shard state for the next epoch has not been caught up yet, thus the two modes IsCaughtUp and NotCaughtUp. CatchingUp is for when apply_chunks is called through catchup_blocks, this is to catch up the shard states for the next epoch